// DESCRIPTION: unanchor item
// © 2020 CatBase Publishing Systems Ltd
// catbase.com
// Written by Dave Saunders

(function() {
	if (app.documents.length > 0 && // must be a document open
			app.selection.length == 1 && // selection must be of single item
			app.selection[0].parent instanceof Character) { // selection must be anchored
		if (parseFloat(app.version) < 6) {
			releaseMe(app.selection[0]);
		} else {
			app.doScript(releaseMe, undefined, app.selection[0], UndoModes.entireScript, "Release Any Anchor");
		}
	} else {
		alert("Please select an inline item.");
	}

	function releaseMe(myPI) {
		var yePage = findPage(myPI);
		var startBounds = myPI.geometricBounds;
		myPI.anchoredObjectSettings.anchoredPosition = AnchorPosition.anchored;
		myPI.anchoredObjectSettings.releaseAnchoredObject();
		if (yePage != null) {
			myPI.move(yePage);
		}
		myPI.move([startBounds[1], startBounds[0]]);
	}

	function findPage(theObj) {
		if (theObj.hasOwnProperty("baseline")) {
			theObj = theObj.parentTextFrames[0];
		}
		while (theObj != null) {
			if (theObj.hasOwnProperty("parentPage")) return theObj.parentPage;
			var whatIsIt = theObj.constructor;
			switch (whatIsIt) {
				case Page : return theObj;
				case Character : theObj = theObj.parentTextFrames[0]; break;
				case Cell : theObj = theObj.insertionPoints[0].parentTextFrames[0]; break;
				case Note : ; case Footnote : theObj = theObj.storyOffset; break;
				case Application : return null;
			}
			if (theObj == null) return null;
			theObj = theObj.parent;
		}
		return theObj
	} // end findPage

}());
